@@ -7,7 +7,7 @@ Attean::API::Binding - Name to term bindings
 
 =head1 VERSION
 
-This document describes Attean::API::Binding version 0.009
+This document describes Attean::API::Binding version 0.010
 
 =head1 DESCRIPTION
 
@@ -71,7 +71,7 @@ otherwise.
 
 use Type::Tiny::Role;
 
-package Attean::API::Binding 0.009 {
+package Attean::API::Binding 0.010 {
 	use Moo::Role;
 	use Scalar::Util qw(blessed);
 	use List::MoreUtils qw(zip);
@@ -108,23 +108,48 @@ package Attean::API::Binding 0.009 {
 		return scalar(@blanks);
 	}
 	
+=item C<< is_ground >>
+
+Returns tue is all the bound values consume L<Attean::API::Term>, false otherwise.
+
+=cut
+
 	sub is_ground {
 		my $self	= shift;
 		my @bad	= grep { not($_->does('Attean::API::Term')) } $self->values;
 		return (scalar(@bad) == 0);
 	}
 	
+=item C<< values_consuming_role( $role ) >>
+
+Returns the list of bound values that consume C<< $role >>.
+
+=cut
+
 	sub values_consuming_role {
 		my $self	= shift;
 		my $role	= shift;
 		return grep { $_->does($role) } $self->values;
 	}
 	
+=item C<< tree_attributes >>
+
+Returns the variables which are bound in this object.
+
+=cut
+
 	sub tree_attributes {
 		my $self	= shift;
 		return $self->variables;
 	}
 	
+=item C<< apply_bindings( $binding ) >>
+
+Construct a new binding by replacing variables with their bound values from
+C<< $binding >>.
+
+=cut
+
 	sub apply_bindings {
 		my $self	= shift;
 		my $class	= ref($self);
@@ -148,7 +173,7 @@ package Attean::API::Binding 0.009 {
 	}
 }
 
-package Attean::API::TripleOrQuadPattern 0.009 {
+package Attean::API::TripleOrQuadPattern 0.010 {
 	use Scalar::Util qw(blessed);
 	use Attean::RDF;
 	use Attean::API::Query;
@@ -225,14 +250,24 @@ package Attean::API::TripleOrQuadPattern 0.009 {
 		}
 		return Attean::Result->new( bindings => \%data );
 	}
+
+	sub canonicalize {
+		my $self	= shift;
+		my $type	= ref($self);
+		my $role	= $self->does('Attean::API::TriplePattern') ? 'Attean::API::TriplePattern' : 'Attean::API::QuadPattern';
+		my $iter	= Attean::ListIterator->new( values => [$self], item_type => $role );
+		my $triples	= $iter->canonical_set();
+		my ($t)		= @$triples;
+		return $t;
+	}
 }
 
-package Attean::API::TripleOrQuad 0.009 {
+package Attean::API::TripleOrQuad 0.010 {
 	use Moo::Role;
 	with 'Attean::API::TripleOrQuadPattern';
 }
 
-package Attean::API::TriplePattern 0.009 {
+package Attean::API::TriplePattern 0.010 {
 	use Moo::Role;
 	use List::MoreUtils qw(zip);
 	use Scalar::Util qw(blessed);
@@ -263,11 +298,6 @@ package Attean::API::TriplePattern 0.009 {
 		return Attean::Triple->new($self->values);
 	}
 	
-	sub as_sparql {
-		my $self	= shift;
-		return join(' ', map { $_->as_sparql } $self->values) . " .\n";
-	}
-	
 	sub apply_triple {
 		my $self	= shift;
 		return $self->apply_statement(@_);
@@ -280,7 +310,7 @@ package Attean::API::TriplePattern 0.009 {
 	with 'Attean::API::TripleOrQuadPattern', 'Attean::API::Binding';
 }
 
-package Attean::API::Triple 0.009 {
+package Attean::API::Triple 0.010 {
 	use Moo::Role;
 	
 	if ($ENV{ATTEAN_TYPECHECK}) {
@@ -315,7 +345,7 @@ package Attean::API::Triple 0.009 {
 	with 'Attean::API::TriplePattern', 'Attean::API::TripleOrQuad', 'Attean::API::Binding';
 }
 
-package Attean::API::QuadPattern 0.009 {
+package Attean::API::QuadPattern 0.010 {
 	use Scalar::Util qw(blessed);
 	use Moo::Role;
 	
@@ -348,7 +378,7 @@ package Attean::API::QuadPattern 0.009 {
 	with 'Attean::API::TripleOrQuadPattern', 'Attean::API::Binding';
 }
 
-package Attean::API::Quad 0.009 {
+package Attean::API::Quad 0.010 {
 	use Moo::Role;
 	
 	if ($ENV{ATTEAN_TYPECHECK}) {
@@ -375,7 +405,7 @@ package Attean::API::Quad 0.009 {
 }
 
 
-package Attean::API::Result 0.009 {
+package Attean::API::Result 0.010 {
 	use Moo::Role;
 	use Scalar::Util qw(refaddr);
 	use Types::Standard qw(HashRef);
@@ -477,7 +507,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014 Gregory Todd Williams.
+Copyright (c) 2014--2016 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
