@@ -7,7 +7,7 @@ Attean::API::Expression - SPARQL expressions
 
 =head1 VERSION
 
-This document describes Attean::API::Expression version 0.008
+This document describes Attean::API::Expression version 0.010
 
 =head1 DESCRIPTION
 
@@ -65,7 +65,7 @@ Returns a string serialization of the expression object.
 
 =cut
 
-package Attean::API::Expression 0.008 {
+package Attean::API::Expression 0.010 {
 	use Moo::Role;
 	use Types::Standard qw(Str);
 	use namespace::clean;
@@ -74,6 +74,7 @@ package Attean::API::Expression 0.008 {
 	
 	has 'operator' => (is => 'ro', isa => Str, required => 1);
 	requires 'is_stable'; # is stable for sorting (won't change across evaluations)
+	requires 'unaggregated_variables';
 	requires 'as_string';
 	requires 'as_sparql';
 	
@@ -99,35 +100,96 @@ package Attean::API::Expression 0.008 {
 	}
 }
 
-package Attean::API::UnaryExpression 0.008 {
+package Attean::API::UnaryExpression 0.010 {
 	use Moo::Role;
+	use AtteanX::SPARQL::Constants;
+	use AtteanX::SPARQL::Token;
+	use namespace::clean;
+	
 	with 'Attean::API::Expression', 'Attean::API::UnaryQueryTree';
+	with 'Attean::API::SPARQLSerializable';
+	
 	sub as_string {
 		my $self	= shift;
 		my ($data)	= @{ $self->children };
 		return sprintf("%s(%s)", $self->operator, $data->as_string);
 	}
-	sub as_sparql {
+
+	my %ops	= (
+		'!'	=> AtteanX::SPARQL::Token->fast_constructor( BANG, -1, -1, -1, -1, ['!'] ),
+		'-'	=> AtteanX::SPARQL::Token->fast_constructor( MINUS, -1, -1, -1, -1, ['-'] ),
+		'+'	=> AtteanX::SPARQL::Token->fast_constructor( PLUS, -1, -1, -1, -1, ['+'] ),
+	);
+
+	sub unaggregated_variables {
 		my $self	= shift;
-		return $self->as_string;
+		my ($child)	= @{ $self->children };
+		return $child->unaggregated_variables;
+	}
+	
+	sub sparql_tokens {
+		my $self	= shift;
+		my $op		= $ops{$self->operator} // die "No operator found in Attean::API::UnaryExpression->sparql_tokens";
+
+		my @tokens;
+		push(@tokens, $op);
+		foreach my $t (@{ $self->children }) {
+			push(@tokens, $t->sparql_tokens->elements);
+		}
+		return Attean::ListIterator->new( values => \@tokens, item_type => 'AtteanX::SPARQL::Token' );
 	}
 }
 
-package Attean::API::BinaryExpression 0.008 {
+package Attean::API::BinaryExpression 0.010 {
 	use Moo::Role;
+	use AtteanX::SPARQL::Constants;
+	use AtteanX::SPARQL::Token;
+	use namespace::clean;
+	
 	with 'Attean::API::Expression', 'Attean::API::BinaryQueryTree';
+	with 'Attean::API::SPARQLSerializable';
+
 	sub as_string {
 		my $self	= shift;
 		my ($lhs, $rhs)	= @{ $self->children };
 		return sprintf("(%s %s %s)", $lhs->as_string, $self->operator, $rhs->as_string);
 	}
-	sub as_sparql {
+
+	sub unaggregated_variables {
 		my $self	= shift;
-		return $self->as_string;
+		return map { $_->unaggregated_variables } @{ $self->children };
+	}
+	
+	my %ops	= (
+		'-'		=> AtteanX::SPARQL::Token->fast_constructor( MINUS, -1, -1, -1, -1, ['-'] ),
+		'+'		=> AtteanX::SPARQL::Token->fast_constructor( PLUS, -1, -1, -1, -1, ['+'] ),
+		'*'		=> AtteanX::SPARQL::Token->fast_constructor( STAR, -1, -1, -1, -1, ['*'] ),
+		'/'		=> AtteanX::SPARQL::Token->fast_constructor( SLASH, -1, -1, -1, -1, ['/'] ),
+		'<'		=> AtteanX::SPARQL::Token->fast_constructor( LT, -1, -1, -1, -1, ['<'] ),
+		'>'		=> AtteanX::SPARQL::Token->fast_constructor( GT, -1, -1, -1, -1, ['>'] ),
+		'<='	=> AtteanX::SPARQL::Token->fast_constructor( LE, -1, -1, -1, -1, ['<='] ),
+		'>='	=> AtteanX::SPARQL::Token->fast_constructor( GE, -1, -1, -1, -1, ['>='] ),
+		'!='	=> AtteanX::SPARQL::Token->fast_constructor( NOTEQUALS, -1, -1, -1, -1, ['!='] ),
+		'='		=> AtteanX::SPARQL::Token->fast_constructor( EQUALS, -1, -1, -1, -1, ['='] ),
+		'&&'	=> AtteanX::SPARQL::Token->fast_constructor( ANDAND, -1, -1, -1, -1, ['&&'] ),
+		'||'	=> AtteanX::SPARQL::Token->fast_constructor( OROR, -1, -1, -1, -1, ['||'] ),
+	);
+	
+	sub sparql_tokens {
+		my $self	= shift;
+		my $op		= $ops{$self->operator} // die "No operator found in Attean::API::BinaryExpression->sparql_tokens";
+
+		my @tokens;
+		foreach my $t (@{ $self->children }) {
+			push(@tokens, $t->sparql_tokens->elements);
+			push(@tokens, $op);
+		}
+		pop(@tokens);
+		return Attean::ListIterator->new( values => \@tokens, item_type => 'AtteanX::SPARQL::Token' );
 	}
 }
 
-package Attean::API::NaryExpression 0.008 {
+package Attean::API::NaryExpression 0.010 {
 	use Moo::Role;
 	with 'Attean::API::Expression', 'Attean::API::QueryTree';
 	sub as_string {
@@ -135,13 +197,19 @@ package Attean::API::NaryExpression 0.008 {
 		my @children	= map { $_->as_string } @{ $self->children };
 		return sprintf("%s(%s)", $self->operator, join(', ', @children));
 	}
+
 	sub as_sparql {
 		my $self	= shift;
 		return $self->as_string;
 	}
+
+	sub unaggregated_variables {
+		my $self	= shift;
+		return map { $_->unaggregated_variables } @{ $self->children };
+	}
 }
 
-package Attean::API::AggregateExpression 0.008 {
+package Attean::API::AggregateExpression 0.010 {
 	use Moo::Role;
 	requires 'operator';
 	requires 'scalar_vars';
@@ -152,10 +220,15 @@ package Attean::API::AggregateExpression 0.008 {
 		my @children	= map { $_->as_string } @{ $self->children };
 		return sprintf("%s(%s)", $self->operator, join(', ', @children));
 	}
+
 	sub as_sparql {
 		my $self	= shift;
 		return $self->as_string;
 	}
+
+	sub unaggregated_variables {
+		return;
+	}
 }
 
 1;
@@ -177,7 +250,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014 Gregory Todd Williams.
+Copyright (c) 2014--2016 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
