@@ -7,7 +7,7 @@ Attean::API::Iterator - Typed iterator
 
 =head1 VERSION
 
-This document describes Attean::API::Iterator version 0.008
+This document describes Attean::API::Iterator version 0.010
 
 =head1 DESCRIPTION
 
@@ -92,11 +92,9 @@ C<< $limit >> elements of the referent.
 Returns a new L<Attean::API::RepeatableIterator> object containing all the
 elements from the referent.
 
-=back
-
 =cut
 
-package Attean::API::Iterator 0.008 {
+package Attean::API::Iterator 0.010 {
 	use Moo::Role;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(Str Object InstanceOf);
@@ -243,6 +241,12 @@ package Attean::API::Iterator 0.008 {
 		return Attean::ListIterator->new( values => \@data, item_type => $self->item_type );
 	}
 	
+=item C<< debug( [$name] ) >>
+
+Print each item as it is consumed (with the string generated by C<< as_string >>), prepended by C<< $name >>.
+
+=cut
+
 	sub debug {
 		my $self	= shift;
 		my $name	= shift // 'Iterator item';
@@ -250,7 +254,7 @@ package Attean::API::Iterator 0.008 {
 	}
 }
 
-package Attean::API::RepeatableIterator 0.008 {
+package Attean::API::RepeatableIterator 0.010 {
 	use Moo::Role;
 	requires 'reset';
 	
@@ -286,7 +290,7 @@ package Attean::API::CanonicalizingBindingIterator {
 	}
 }
 
-package Attean::API::ResultOrTermIterator 0.008 {
+package Attean::API::ResultOrTermIterator 0.010 {
 	use Moo::Role;
 	use Types::Standard qw(ArrayRef Str);
 	has 'variables' => (is => 'rw', isa => ArrayRef[Str], default => sub { [] });
@@ -305,7 +309,7 @@ package Attean::API::ResultOrTermIterator 0.008 {
 	}
 }
 
-package Attean::API::TripleIterator 0.008 {
+package Attean::API::TripleIterator 0.010 {
 	use Moo::Role;
 	with 'Attean::API::CanonicalizingBindingIterator';
 	sub as_quads {
@@ -315,12 +319,12 @@ package Attean::API::TripleIterator 0.008 {
 	}
 }
 
-package Attean::API::QuadIterator 0.008 {
+package Attean::API::QuadIterator 0.010 {
 	use Moo::Role;
 	with 'Attean::API::CanonicalizingBindingIterator';
 }
 
-package Attean::API::MixedStatementIterator 0.008 {
+package Attean::API::MixedStatementIterator 0.010 {
 	use Moo::Role;
 	with 'Attean::API::CanonicalizingBindingIterator';
 	sub as_quads {
@@ -333,7 +337,7 @@ package Attean::API::MixedStatementIterator 0.008 {
 	}
 }
 
-package Attean::API::ResultIterator 0.008 {
+package Attean::API::ResultIterator 0.010 {
 	use Moo::Role;
 	use Types::Standard qw(Str ArrayRef);
 	with 'Attean::API::CanonicalizingBindingIterator';
@@ -354,7 +358,7 @@ package Attean::API::ResultIterator 0.008 {
 	}
 }
 
-package Attean::API::TermIterator 0.008 {
+package Attean::API::TermIterator 0.010 {
 	use Moo::Role;
 	sub canonicalize {
 		my $self	= shift;
@@ -368,6 +372,8 @@ package Attean::API::TermIterator 0.008 {
 
 __END__
 
+=back
+
 =head1 BUGS
 
 Please report any bugs or feature requests to through the GitHub web interface
@@ -385,7 +391,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014 Gregory Todd Williams.
+Copyright (c) 2014--2016 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
