@@ -7,7 +7,7 @@ Attean::API::Term - RDF Terms
 
 =head1 VERSION
 
-This document describes Attean::API::Term version 0.009
+This document describes Attean::API::Term version 0.010
 
 =head1 DESCRIPTION
 
@@ -39,11 +39,9 @@ This role provides default implementations of the following methods:
 
 Returns a string serialization of the term.
 
-=back
-
 =cut
 
-package Attean::API::Term 0.009 {
+package Attean::API::Term 0.010 {
 	use Moo::Role;
 	
 	with 'Attean::API::TermOrVariable', 'Attean::API::ResultOrTerm';
@@ -53,9 +51,13 @@ package Attean::API::Term 0.009 {
 	sub as_string {
 		shift->ntriples_string();
 	}
-	sub as_sparql {
-		shift->ntriples_string();
-	}
+
+=item C<< ebv >>
+
+Returns true if the term has a true SPARQL "effective boolean value", false otherwise.
+
+=cut
+
 	sub ebv { return 0; }
 	
 	requires 'compare';
@@ -104,7 +106,7 @@ package Attean::API::Term 0.009 {
 	}
 }
 
-package Attean::API::Literal 0.009 {
+package Attean::API::Literal 0.010 {
 	use Moo::Role;
 	use IRI;
 	use Scalar::Util qw(blessed);
@@ -160,9 +162,27 @@ package Attean::API::Literal 0.009 {
 	sub sparql_tokens {
 		my $self	= shift;
 		my @tokens;
-		my $value	= $self->__ntriples_string;
-		my $t	= AtteanX::SPARQL::Token->fast_constructor( STRING1D, -1, -1, -1, -1, [$value] );
-		return Attean::ListIterator->new( values => [$t], item_type => 'AtteanX::SPARQL::Token' );
+		
+		my $dt = $self->datatype;
+		if ($self->does('Attean::API::NumericLiteral') and $dt->value eq 'http://www.w3.org/2001/XMLSchema#integer') {
+			if ($self->value =~ /^\d+$/) {
+				my $t	= AtteanX::Parser::Turtle::Token->fast_constructor( INTEGER, -1, -1, -1, -1, [$self->value] );
+				return Attean::ListIterator->new( values => [$t], item_type => 'AtteanX::SPARQL::Token' );
+			}
+		}
+		
+		my $t	= AtteanX::SPARQL::Token->fast_constructor( STRING1D, -1, -1, -1, -1, [$self->value] );
+		push(@tokens, $t);
+		if (my $lang = $self->language) {
+			my $l	= AtteanX::SPARQL::Token->fast_constructor( LANG, -1, -1, -1, -1, ["$lang"] );
+			push(@tokens, $l);
+		} else {
+			if ($dt->value ne 'http://www.w3.org/2001/XMLSchema#string') {
+				push(@tokens, AtteanX::Parser::Turtle::Token->hathat);
+				push(@tokens, $dt->sparql_tokens->elements);
+			}
+		}
+		return Attean::ListIterator->new( values => \@tokens, item_type => 'AtteanX::SPARQL::Token' );
 	}
 	
 	sub ebv {
@@ -270,7 +290,7 @@ package Attean::API::Literal 0.009 {
 	};
 }
 
-package Attean::API::DateTimeLiteral 0.009 {
+package Attean::API::DateTimeLiteral 0.010 {
 	use Moo::Role;
 	use DateTime::Format::W3CDTF;
 	use namespace::clean;
@@ -281,12 +301,12 @@ package Attean::API::DateTimeLiteral 0.009 {
 	}
 }
 
-package Attean::API::CanonicalizingLiteral 0.009 {
+package Attean::API::CanonicalizingLiteral 0.010 {
 	use Moo::Role;
 	requires 'canonicalized_term';
 }
 
-package Attean::API::NumericLiteral 0.009 {
+package Attean::API::NumericLiteral 0.010 {
 	use Moo::Role;
 	use Scalar::Util qw(blessed looks_like_number);
 	use namespace::clean;
@@ -477,7 +497,7 @@ package Attean::API::NumericLiteral 0.009 {
 	with 'Attean::API::Literal', 'Attean::API::CanonicalizingLiteral';
 }
 
-package Attean::API::Blank 0.009 {
+package Attean::API::Blank 0.010 {
 	use Moo::Role;
 	use Scalar::Util qw(blessed);
 	use AtteanX::SPARQL::Constants;
@@ -491,7 +511,8 @@ package Attean::API::Blank 0.009 {
 	
 	sub sparql_tokens {
 		my $self	= shift;
-		die;
+		my $t	= AtteanX::SPARQL::Token->fast_constructor( BNODE, -1, -1, -1, -1, [$self->value] );
+		return Attean::ListIterator->new( values => [$t], item_type => 'AtteanX::SPARQL::Token' );
 	}
 	
 	sub compare {
@@ -502,7 +523,7 @@ package Attean::API::Blank 0.009 {
 	}
 }
 
-package Attean::API::IRI 0.009 {
+package Attean::API::IRI 0.010 {
 	use Moo::Role;
 	use IRI;
 	use Scalar::Util qw(blessed);
@@ -517,8 +538,13 @@ package Attean::API::IRI 0.009 {
 	
 	sub sparql_tokens {
 		my $self	= shift;
-		my $t	= AtteanX::SPARQL::Token->fast_constructor( IRI, -1, -1, -1, -1, [$self->value] );
-		return Attean::ListIterator->new( values => [$t], item_type => 'AtteanX::SPARQL::Token' );
+		my @tokens;
+		if ($self->value eq '') {
+			push(@tokens, AtteanX::Parser::Turtle::Token->a);
+		} else {
+			push(@tokens, AtteanX::SPARQL::Token->fast_constructor( IRI, -1, -1, -1, -1, [$self->value] ));
+		}
+		return Attean::ListIterator->new( values => \@tokens, item_type => 'AtteanX::SPARQL::Token' );
 	}
 	
 	sub compare {
@@ -550,6 +576,8 @@ package Attean::API::IRI 0.009 {
 
 __END__
 
+=back
+
 =head1 BUGS
 
 Please report any bugs or feature requests to through the GitHub web interface
@@ -565,7 +593,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014 Gregory Todd Williams.
+Copyright (c) 2014--2016 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
