@@ -1,13 +1,34 @@
 use v5.14;
 use warnings;
 
+=head1 NAME
+
+Attean::BindingEqualityTest - Test for equality of binding sets with bnode isomorphism
+
+=head1 VERSION
+
+This document describes Attean::BindingEqualityTest version 0.010
+
+=head1 SYNOPSIS
+
+  use v5.14;
+  use Attean;
+  my $test	= Attean::BindingEqualityTest->new();
+  if ($test->equals($iter_a, $iter_b)) {
+    say "Iterators contain equivalent bindings";
+  }
+
+=head1 DESCRIPTION
+
+...
+
 =head1 METHODS
 
 =over 4
 
 =cut
 
-package Attean::BindingEqualityTest 0.009 {
+package Attean::BindingEqualityTest 0.010 {
 	use v5.14;
 	use warnings;
 	use Moo;
@@ -18,11 +39,11 @@ package Attean::BindingEqualityTest 0.009 {
 	use Attean::RDF;
 	use namespace::clean;
 	
-	our $debug	= 0;
+	with 'MooX::Log::Any';
 	
 	has error => (is => 'rw', isa => Str, init_arg => undef);
 	
-	sub coerce {
+	sub _coerce {
 		my $o	= shift;
 		if ($o->does('Attean::API::Model')) {
 			return $o->get_quads;
@@ -47,7 +68,7 @@ there exists a bijection between the RDF statements of the invocant and $graph).
 
 	sub _check_equality {
 		my $self	= shift;
-		my ($a, $b)	= map { coerce($_) } @_;
+		my ($a, $b)	= map { _coerce($_) } @_;
 		
 		my @graphs	= ($a, $b);
 		my ($ba, $nba)	= $self->split_blank_statements($a);
@@ -111,7 +132,7 @@ solutions, the solution returned is arbitrary.
 
 	sub _check_subgraph {
 		my $self	= shift;
-		my ($a, $b)	= map { coerce($_) } @_;
+		my ($a, $b)	= map { _coerce($_) } @_;
 	
 		my @graphs	= ($a, $b);
 		my ($ba, $nba)	= $self->split_blank_statements($a);
@@ -170,21 +191,21 @@ solutions, the solution returned is arbitrary.
 				Attean::Blank->new($_)->as_string => Attean::Blank->new($mapping_str{$_})
 			} (keys %mapping_str);
 			my $mapper	= Attean::TermMap->rewrite_map(\%mapping);
-			warn "trying mapping: " . Dumper($mapping) if ($debug);
+			$self->log->trace("trying mapping: " . Dumper($mapping));
 		
 			my %bb	= %bb_master;
 			foreach my $st (@$ba) {
 				my $mapped_st	= $st->apply_map($mapper)->as_string;
-				warn "checking for '$mapped_st' in " . Dumper(\%bb) if ($debug);
+				$self->log->trace("checking for '$mapped_st' in " . Dumper(\%bb));
 				if ($bb{ $mapped_st }) {
-					warn "Found mapping for binding: " . Dumper($mapped_st) if ($debug);
+					$self->log->trace("Found mapping for binding: " . Dumper($mapped_st));
 					delete $bb{ $mapped_st };
 				} else {
-					warn "No mapping found for binding: " . Dumper($mapped_st) if ($debug);
+					$self->log->trace("No mapping found for binding: " . Dumper($mapped_st));
 					next MAPPING;
 				}
 			}
-			$self->error("found mapping: " . Dumper(\%mapping_str)) if ($debug);
+			$self->error("found mapping: " . Dumper(\%mapping_str));
 			return \%mapping_str;
 		}
 	
@@ -221,4 +242,23 @@ __END__
 
 =back
 
+=head1 BUGS
+
+Please report any bugs or feature requests to through the GitHub web interface
+at L<https://github.com/kasei/attean/issues>.
+
+=head1 SEE ALSO
+
+L<http://www.perlrdf.org/>
+
+=head1 AUTHOR
+
+Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
+
+=head1 COPYRIGHT
+
+Copyright (c) 2014--2016 Gregory Todd Williams.
+This program is free software; you can redistribute it and/or modify it under
+the same terms as Perl itself.
+
 =cut
