@@ -7,7 +7,7 @@ Attean::ListIterator - Iterator implementation backed by a list/array of values
 
 =head1 VERSION
 
-This document describes Attean::ListIterator version 0.009
+This document describes Attean::ListIterator version 0.010
 
 =head1 SYNOPSIS
 
@@ -49,8 +49,9 @@ iterator.
 
 =cut
 
-package Attean::ListIterator 0.009 {
+package Attean::ListIterator 0.010 {
 	use Moo;
+	use Scalar::Util qw(blessed);
 	use Type::Tiny::Role;
 	use Types::Standard qw(ArrayRef Int);
 	use namespace::clean;
@@ -63,7 +64,7 @@ package Attean::ListIterator 0.009 {
 		my $role	= $self->item_type;
 		foreach my $item (@{ $self->values }) {
 			if (Role::Tiny->is_role($role)) {
-				die "ListIterator item is not a $role" unless ($item->does($role));
+				die "ListIterator item <$item> is not a $role" unless (blessed($item) and $item->does($role));
 			}
 		}
 	}
@@ -120,7 +121,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014 Gregory Todd Williams.
+Copyright (c) 2014--2016 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
