@@ -7,7 +7,7 @@ Attean::TermMap - Mapping terms to new terms
 
 =head1 VERSION
 
-This document describes Attean::TermMap version 0.009
+This document describes Attean::TermMap version 0.010
 
 =head1 SYNOPSIS
 
@@ -25,13 +25,24 @@ skolemize nodes, or map the nodes in some other, custom way.
 
 It conforms to the L<Attean::API::Mapper> role.
 
+=head1 ATTRIBUTES
+
+=over 4
+
+=item C<< mapper >>
+
+A CODE reference that will map L<Attean::API::Term> objects to (possibly different)
+term objects.
+
+=back
+
 =head1 CLASS METHODS
 
 =over 4
 
 =cut
 
-package Attean::TermMap 0.009 {
+package Attean::TermMap 0.010 {
 	use Moo;
 	use Types::Standard qw(CodeRef);
 	use Attean::API::Binding;
@@ -119,6 +130,14 @@ alphabetic names (e.g. _:a, _:b).
 		});
 	}
 
+=item C<< rewrite_map( \%map ) >>
+
+Given C<< %map >> whose keys are term C<< as_string >> serializations, and
+objects are L<Attean::API::Term> objects, returns a new term map object that
+maps terms matching entries in C<< %map >>, and all other terms to themselves.
+
+=cut
+
 	sub rewrite_map {
 		my $class	= shift;
 		my $map		= shift;
@@ -184,7 +203,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014 Gregory Todd Williams.
+Copyright (c) 2014--2016 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
