@@ -7,7 +7,7 @@ Attean::Variable - Pattern matching variables
 
 =head1 VERSION
 
-This document describes Attean::Variable version 0.009
+This document describes Attean::Variable version 0.010
 
 =head1 SYNOPSIS
 
@@ -21,9 +21,19 @@ This document describes Attean::Variable version 0.009
 The Attean::Variable class represents variables for use in pattern matching.
 It conforms to the L<Attean::API::TermOrVariable|Attean::API> role.
 
+=head1 ATTRIBUTES
+
+=over 4
+
+=item C<< value >>
+
+=item C<< ntriples_string >>
+
+=back
+
 =cut
 
-package Attean::Variable 0.009 {
+package Attean::Variable 0.010 {
 	use Moo;
 	use Types::Standard qw(Str);
 	use Data::UUID;
@@ -32,7 +42,8 @@ package Attean::Variable 0.009 {
 	has 'value' => (is => 'ro', isa => Str, required => 1);
 	has 'ntriples_string'	=> (is => 'ro', isa => Str, lazy => 1, builder => '_ntriples_string');
 
-	with 'Attean::API::Variable', 'Attean::API::TermOrVariable';
+	with 'Attean::API::Variable';
+	with 'Attean::API::TermOrVariable';
 	
 	around BUILDARGS => sub {
 		my $orig 	= shift;
@@ -71,7 +82,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014 Gregory Todd Williams.
+Copyright (c) 2014--2016 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
