@@ -7,7 +7,7 @@ AtteanX::Parser::NTuples - Shared functionality for N-Triples and N-Quads parser
 
 =head1 VERSION
 
-This document describes AtteanX::Parser::NTuples version 0.009
+This document describes AtteanX::Parser::NTuples version 0.010
 
 =head1 SYNOPSIS
 
@@ -23,14 +23,30 @@ This document describes AtteanX::Parser::NTuples version 0.009
 
 =cut
 
-package AtteanX::Parser::NTuples 0.009 {
+package AtteanX::Parser::NTuples 0.010 {
 	use utf8;
 	use Moo;
 	use Attean;
 	use Encode qw(decode);
 	use namespace::clean;
+
+=item C<< parse_term_from_string( $bytes ) >>
+
+This method is deprecated, as the name was misleading.
+Calls should be replaced with C<< parse_term_from_bytes >>.
 	
+=item C<< parse_term_from_bytes( $bytes ) >>
+
+Parses the given C<< $bytes >> and returns a corresponding L<Attean::API::Term> object.
+
+=cut
+
 	sub parse_term_from_string {
+# 		TODO: warn "parse_term_from_string is now called parse_term_from_bytes\n";
+		return shift->parse_term_from_bytes(@_);
+	}
+	
+	sub parse_term_from_bytes {
 		my $self	= shift;
 		my $string	= shift;
 		my $n = $self->_eat_node( 0, $string );
@@ -265,7 +281,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2012 Gregory Todd Williams. This
+Copyright (c) 2014--2016 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
