@@ -4,7 +4,7 @@ AtteanX::Parser::SPARQLJSON - SPARQL JSON Parser
 
 =head1 VERSION
 
-This document describes AtteanX::Parser::SPARQLJSON version 0.008
+This document describes AtteanX::Parser::SPARQLJSON version 0.010
 
 =head1 SYNOPSIS
 
@@ -16,6 +16,18 @@ This document describes AtteanX::Parser::SPARQLJSON version 0.008
 
 ...
 
+=head1 ATTRIBUTES
+
+=over 4
+
+=item C<< canonical_media_type >>
+
+=item C<< media_types >>
+
+=item C<< file_extensions >>
+
+=back
+
 =head1 METHODS
 
 =over 4
@@ -25,42 +37,27 @@ This document describes AtteanX::Parser::SPARQLJSON version 0.008
 use v5.14;
 use warnings;
 
-package AtteanX::Parser::SPARQLJSON 0.008 {
+package AtteanX::Parser::SPARQLJSON 0.010 {
 	use Attean;
 	use Moo;
 	use JSON;
 	use Encode qw(decode);
 	
-=item C<< canonical_media_type >>
-
-Returns the canonical media type for SPARQL JSON: application/sparql-results+json.
-
-=cut
-
 	sub canonical_media_type { return "application/sparql-results+json" }
 
-=item C<< media_types >>
-
-Returns a list of media types that may be parsed with the SPARQL JSON parser:
-application/sparql-results+json.
-
-=cut
-
 	sub media_types {
 		return [qw(application/sparql-results+json)];
 	}
 	
-=item C<< file_extensions >>
-
-Returns a list of file extensions that may be parsed with the parser.
-
-=cut
-
 	sub file_extensions { return [qw(srj)] }
 
 	with 'Attean::API::ResultOrTermParser';
 	with 'Attean::API::AtOnceParser';
 
+=item C<< parse_list_from_io( $fh ) >>
+
+=cut
+
 	sub parse_list_from_io {
 		my $self	= shift;
 		my $io		= shift;
@@ -68,6 +65,10 @@ Returns a list of file extensions that may be parsed with the parser.
 		return $self->parse_list_from_bytes($data);
 	}
 	
+=item C<< parse_list_from_bytes( $bytes ) >>
+
+=cut
+
 	sub parse_list_from_bytes {
 		my $self	= shift;
 		my $octets	= shift;
@@ -103,7 +104,6 @@ Returns a list of file extensions that may be parsed with the parser.
 							my $dt		= $value->{datatype};
 							$data{ $v }	= Attean::Literal->new( value => $data, datatype => $dt );
 						} else {
-							warn Dumper($data, $b);
 							die "Unknown node type $type during parsing of SPARQL JSON Results";
 						}
 					}
@@ -134,7 +134,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2012 Gregory Todd Williams. This
+Copyright (c) 2014--2016 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
