@@ -7,7 +7,7 @@ AtteanX::Parser::Turtle::Lexer - Tokenizer for parsing Turtle, TriG, and N-Tripl
 
 =head1 VERSION
 
-This document describes AtteanX::Parser::Turtle::Lexer version 0.009
+This document describes AtteanX::Parser::Turtle::Lexer version 0.010
 
 =head1 SYNOPSIS
 
@@ -23,7 +23,7 @@ This document describes AtteanX::Parser::Turtle::Lexer version 0.009
 
 =cut
 
-package AtteanX::Parser::Turtle::Lexer 0.009 {
+package AtteanX::Parser::Turtle::Lexer 0.010 {
 	use AtteanX::Parser::Turtle::Constants;
 	use v5.14;
 	use strict;
@@ -47,12 +47,12 @@ package AtteanX::Parser::Turtle::Lexer 0.009 {
 	my $r_bnode_id				= qr"(?:${r_PN_CHARS_U}|[0-9])((${r_PN_CHARS}|[.])*${r_PN_CHARS})?"o;
 
 	my $r_PN_CHARS_BASE			= qr/([A-Z]|[a-z]|[\x{00C0}-\x{00D6}]|[\x{00D8}-\x{00F6}]|[\x{00F8}-\x{02FF}]|[\x{0370}-\x{037D}]|[\x{037F}-\x{1FFF}]|[\x{200C}-\x{200D}]|[\x{2070}-\x{218F}]|[\x{2C00}-\x{2FEF}]|[\x{3001}-\x{D7FF}]|[\x{F900}-\x{FDCF}]|[\x{FDF0}-\x{FFFD}]|[\x{10000}-\x{EFFFF}])/o;
-	my $r_PN_PREFIX				= qr/(${r_PN_CHARS_BASE}((${r_PN_CHARS}|[.])*${r_PN_CHARS})?)/o;
-	my $r_PN_LOCAL_ESCAPED		= qr{(\\([-~.!&'()*+,;=/?#@%_\$]))|%[0-9A-Fa-f]{2}}o;
-	my $r_PN_LOCAL				= qr/((${r_PN_CHARS_U}|[:0-9]|${r_PN_LOCAL_ESCAPED})((${r_PN_CHARS}|${r_PN_LOCAL_ESCAPED}|[:.])*(${r_PN_CHARS}|[:]|${r_PN_LOCAL_ESCAPED}))?)/o;
-	my $r_PN_LOCAL_BNODE		= qr/((${r_PN_CHARS_U}|[0-9])((${r_PN_CHARS}|[.])*${r_PN_CHARS})?)/o;
-	my $r_PNAME_NS				= qr/((${r_PN_PREFIX})?:)/o;
-	my $r_PNAME_LN				= qr/(${r_PNAME_NS}${r_PN_LOCAL})/o;
+	my $r_PN_PREFIX				= qr/(?:${r_PN_CHARS_BASE}(?:(?:${r_PN_CHARS}|[.])*${r_PN_CHARS})?)/o;
+	my $r_PN_LOCAL_ESCAPED		= qr{(?:\\(?:[-~.!&'()*+,;=/?#@%_\$]))|%[0-9A-Fa-f]{2}}o;
+	our $r_PN_LOCAL				= qr/(?:(?:${r_PN_CHARS_U}|[:0-9]|${r_PN_LOCAL_ESCAPED})(?:(?:${r_PN_CHARS}|${r_PN_LOCAL_ESCAPED}|[:.])*(?:${r_PN_CHARS}|[:]|${r_PN_LOCAL_ESCAPED}))?)/o;
+	my $r_PN_LOCAL_BNODE		= qr/(?:(?:${r_PN_CHARS_U}|[0-9])(?:(?:${r_PN_CHARS}|[.])*${r_PN_CHARS})?)/o;
+	our $r_PNAME_NS				= qr/(?:(?:${r_PN_PREFIX})?:)/o;
+	our $r_PNAME_LN				= qr/(?:${r_PNAME_NS}${r_PN_LOCAL})/o;
 
 	with 'AtteanX::API::Lexer';
 
@@ -145,10 +145,10 @@ Returns the next token present in the input.
 					return $self->new_token(BOOLEAN, $start_line, $start_column, $bool);
 				} elsif ($self->buffer =~ /^BASE(?!:)\b/oi) {
 					$self->read_length(4);
-					return $self->new_token(SPARQLBASE, $start_line, $start_column);
+					return $self->new_token(BASE, $start_line, $start_column);
 				} elsif ($self->buffer =~ /^PREFIX(?!:)\b/io) {
 					$self->read_length(6);
-					return $self->new_token(SPARQLPREFIX, $start_line, $start_column);
+					return $self->new_token(PREFIX, $start_line, $start_column);
 				} else {
 					return $self->_get_pname;
 				}
@@ -403,10 +403,10 @@ Returns the next token present in the input.
 		$self->get_char_safe('@');
 		if ($self->buffer =~ /^base/o) {
 			$self->read_word('base');
-			return $self->new_token(BASE, $self->start_line, $self->start_column);
+			return $self->new_token(TURTLEBASE, $self->start_line, $self->start_column);
 		} elsif ($self->buffer =~ /^prefix/o) {
 			$self->read_word('prefix');
-			return $self->new_token(PREFIX, $self->start_line, $self->start_column);
+			return $self->new_token(TURTLEPREFIX, $self->start_line, $self->start_column);
 		} else {
 			if ($self->buffer =~ /^[a-zA-Z]+(-[a-zA-Z0-9]+)*\b/o) {
 				my $lang	= $self->read_length($+[0]);
@@ -444,7 +444,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2012 Gregory Todd Williams. This
+Copyright (c) 2014--2016 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
