@@ -7,7 +7,7 @@ AtteanX::SPARQL::Constants - Constant definitions for use in parsing and seriali
 
 =head1 VERSION
 
-This document describes AtteanX::SPARQL::Constants version 0.009
+This document describes AtteanX::SPARQL::Constants version 0.010
 
 =head1 SYNOPSIS
 
@@ -19,40 +19,25 @@ This document describes AtteanX::SPARQL::Constants version 0.009
 
 =cut
 
-package AtteanX::SPARQL::Constants 0.009 {
+package AtteanX::SPARQL::Constants 0.010 {
 	use v5.14;
 	use warnings;
-
+	use AtteanX::Parser::Turtle::Constants;
+	
 	our $VERSION;
 	our @EXPORT;
+	our @LOCAL_TYPES;
 	BEGIN {
-		$VERSION				= 0.009;
-		@EXPORT = qw(
-			A
+		$VERSION				= 0.010;
+		@LOCAL_TYPES	= qw(
 			ANDAND
 			ANON
 			BANG
-			BASE
-			BNODE
-			BOOLEAN
-			COMMA
-			COMMENT
-			DECIMAL
-			DOT
-			DOUBLE
-			EQUALS
 			GE
 			GT
 			HAT
-			HATHAT
-			INTEGER
-			IRI
 			KEYWORD
-			LANG
-			LBRACE
-			LBRACKET
 			LE
-			LPAREN
 			LT
 			MINUS
 			NIL
@@ -60,23 +45,13 @@ package AtteanX::SPARQL::Constants 0.009 {
 			OR
 			OROR
 			PLUS
-			PREFIX
-			PREFIXNAME
 			QUESTION
-			RBRACE
-			RBRACKET
-			RPAREN
-			SEMICOLON
 			SLASH
 			STAR
-			STRING1D
-			STRING1S
-			STRING3D
-			STRING3S
 			VAR
-			WS
 			decrypt_constant
-		)
+		);
+		@EXPORT = (@AtteanX::Parser::Turtle::Constants::EXPORT, @LOCAL_TYPES);
 	};
 	use base 'Exporter';
 
@@ -84,8 +59,8 @@ package AtteanX::SPARQL::Constants 0.009 {
 		my %mapping;
 		my %reverse;
 		BEGIN {
-			my $cx	= 0;
-			foreach my $name (grep { $_ ne 'decrypt_constant' } @EXPORT) {
+			my $cx	= scalar(@AtteanX::Parser::Turtle::Constants::EXPORT) - 1;
+			foreach my $name (grep { $_ ne 'decrypt_constant' } @LOCAL_TYPES) {
 				my $value	= ++$cx;
 				$reverse{ $value }	= $name;
 				$mapping{ $name }	= $value;
@@ -99,7 +74,15 @@ Returns the token name for the given token type.
 
 =cut
 
-		sub decrypt_constant { my $num	= +shift; $reverse{$num} }
+		no warnings 'redefine';
+		sub decrypt_constant {
+			my $num	= +shift;
+			if (exists $reverse{$num}) {
+				return $reverse{$num};
+			} else {
+				return AtteanX::Parser::Turtle::Constants::decrypt_constant($num);
+			}
+		}
 	}
 }
 
@@ -118,9 +101,11 @@ at L<https://github.com/kasei/perlrdf/issues>.
 
 Toby Inkster C<< <tobyink@cpan.org> >>
 
+Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
+
 =head1 COPYRIGHT
 
-Copyright (c) 2012 Toby Inkster. This
+Copyright (c) 2014--2016 Toby Inkster. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
