@@ -4,7 +4,7 @@ AtteanX::Serializer::SPARQLHTML - SPARQL Results HTML Serializer
 
 =head1 VERSION
 
-This document describes AtteanX::Serializer::SPARQLHTML version 0.009
+This document describes AtteanX::Serializer::SPARQLHTML version 0.010
 
 =head1 SYNOPSIS
 
@@ -16,6 +16,14 @@ This document describes AtteanX::Serializer::SPARQLHTML version 0.009
 
 ...
 
+=head1 ATTRIBUTES
+
+=over 4
+
+=item C<< canonical_media_type >>
+
+=back
+
 =head1 METHODS
 
 =over 4
@@ -25,7 +33,7 @@ This document describes AtteanX::Serializer::SPARQLHTML version 0.009
 use v5.14;
 use warnings;
 
-package AtteanX::Serializer::SPARQLHTML 0.009 {
+package AtteanX::Serializer::SPARQLHTML 0.010 {
 	use Moo;
 	use Types::Standard qw(Str Bool ArrayRef);
 	use Encode qw(encode);
@@ -111,11 +119,17 @@ and returns the serialization as a UTF-8 encoded byte string.
 		my $iter	= shift;
 		my $data	= '';
 		open(my $fh, '>:utf8', \$data);
-		return $self->serialize_iter_to_io($fh, $iter);
+		$self->serialize_iter_to_io($fh, $iter);
 		close($fh);
 		return $data;
 	}
 
+=item C<< node_as_html($node) >>
+
+Serializes the L<Attean::API::Term> object as HTML.
+
+=cut
+
 	sub node_as_html {
 		my $self	= shift;
 		my $node	= shift;
@@ -167,7 +181,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2012 Gregory Todd Williams. This
+Copyright (c) 2014--2016 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
