@@ -4,7 +4,7 @@ AtteanX::Serializer::SPARQLXML - SPARQL Results XML Serializer
 
 =head1 VERSION
 
-This document describes AtteanX::Serializer::SPARQLXML version 0.009
+This document describes AtteanX::Serializer::SPARQLXML version 0.010
 
 =head1 SYNOPSIS
 
@@ -16,6 +16,14 @@ This document describes AtteanX::Serializer::SPARQLXML version 0.009
 
 ...
 
+=head1 ATTRIBUTES
+
+=over 4
+
+=item C<< canonical_media_type >>
+
+=back
+
 =head1 METHODS
 
 =over 4
@@ -25,7 +33,7 @@ This document describes AtteanX::Serializer::SPARQLXML version 0.009
 use v5.14;
 use warnings;
 
-package AtteanX::Serializer::SPARQLXML 0.009 {
+package AtteanX::Serializer::SPARQLXML 0.010 {
 	use Moo;
 	use Types::Standard qw(Str ArrayRef);
 	use Encode qw(encode);
@@ -104,7 +112,7 @@ END
 						$label	=~ s/"/&quot;/g;
 						print $fh qq(\t\t\t<binding name="${name}"><bnode>${label}</bnode></binding>\n);
 					} else {
-						die;
+						die "Term object has an unrecognized type: " . ref($term);
 					}
 				}
 			}
@@ -152,7 +160,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2012 Gregory Todd Williams. This
+Copyright (c) 2014--2016 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
